<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="bg">
<context>
    <name>HiddenShortcutsDialog</name>
    <message>
        <location filename="../shortcuts.ui" line="14"/>
        <source>Hidden Shortcuts</source>
        <translation>Скрити клавишни комбинации</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="20"/>
        <source>These hard coded shortcuts will be overridden if they are also assigned to other actions in Preferences → Shortcuts.</source>
        <translation>Тези твърдо кодирани клавишни комбинации ще бъдат отменени, ако бъдат присвоени и на други действия в Предпочитания → Преки пътища.</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="34"/>
        <source>Shortcut</source>
        <translation>Клавишна комбинация</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="39"/>
        <source>Action</source>
        <translation>Действие</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="44"/>
        <source>Esc</source>
        <translation>Esc</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="47"/>
        <source>Close window or exit fullscreen mode</source>
        <translation>Затваряне на прозореца или излизане от режим на цял екран</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="52"/>
        <source>Right</source>
        <translation>Дясно</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="55"/>
        <location filename="../shortcuts.ui" line="63"/>
        <source>Next image</source>
        <translation>Следващо изображение</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="60"/>
        <source>Space</source>
        <translation>Space</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="68"/>
        <source>End</source>
        <translation>Край</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="71"/>
        <source>Last image</source>
        <translation>Последно изображение</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="76"/>
        <source>Left</source>
        <translation>Ляво</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="79"/>
        <location filename="../shortcuts.ui" line="87"/>
        <source>Previous image</source>
        <translation>Предишно изображение</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="84"/>
        <source>Backspace</source>
        <translation>Backspace</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="92"/>
        <source>Home</source>
        <translation>Домашна папка</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="95"/>
        <source>First image</source>
        <translation>Първо изображение</translation>
    </message>
</context>
<context>
    <name>LxImage::Application</name>
    <message>
        <location filename="../application.cpp" line="94"/>
        <source>Start in fullscreen (can be useful with tiling window managers)</source>
        <translation>Стартиране на цял екран (може да бъде полезно при мениджъри на прозорци с плочки)</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="102"/>
        <source>Take a screenshot (deprecated, please use screengrab instead)</source>
        <translation>Снимане на екрана (спряна поддръжка, моля вместо това използвайте screengrab)</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="111"/>
        <source>DIR</source>
        <translation>DIR</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="111"/>
        <source>Take a screenshot and save it to the directory without showing the GUI (deprecated, please use screengrab instead)</source>
        <translation>Снимане на екрана и запазване без показване на графичния интерфейс (неподдържано, моля вместо това използвайте screengrab)</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="117"/>
        <source>[FILE1, FILE2,...]</source>
        <translation>[ФАЙЛ1,ФАЙЛ2,...]</translation>
    </message>
</context>
<context>
    <name>LxImage::ImageShackUpload</name>
    <message>
        <location filename="../upload/imageshackupload.cpp" line="50"/>
        <source>unknown error response</source>
        <translation>отговор неизвестна грешка</translation>
    </message>
</context>
<context>
    <name>LxImage::ImgBBUpload</name>
    <message>
        <location filename="../upload/imgbbupload.cpp" line="44"/>
        <source>unknown error response</source>
        <translation>отговор неизвестна грешка</translation>
    </message>
</context>
<context>
    <name>LxImage::ImgurUpload</name>
    <message>
        <location filename="../upload/imgurupload.cpp" line="47"/>
        <source>unknown error response</source>
        <translation>отговор неизвестна грешка</translation>
    </message>
</context>
<context>
    <name>LxImage::MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="277"/>
        <source>About</source>
        <translation>Относно</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="279"/>
        <source>A simple and fast image viewer</source>
        <translation>Опростена и бърза програма за преглед на изображения</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="281"/>
        <source>Copyright (C) </source>
        <translation>Авторски права (C) </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="281"/>
        <source>2013-2021</source>
        <translation>2013-2021</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="283"/>
        <source>LXQt Project</source>
        <translation>Проекта LXQt</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="285"/>
        <source>Development: </source>
        <translation>Разработка: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="287"/>
        <source>Author: </source>
        <translation>Автор: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="515"/>
        <source>Open File</source>
        <translation>Отваряне на файл</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="516"/>
        <location filename="../mainwindow.cpp" line="551"/>
        <source>Image files (%1)</source>
        <translation>Файлове с изображения (%1)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="529"/>
        <source>Open directory</source>
        <translation>Отваряне на директория</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="550"/>
        <source>Save File</source>
        <translation>Запазване на файл</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="839"/>
        <source>[*]%1 (Loading...) - Image Viewer</source>
        <translation>[*]%1 (Зареждане...) - Преглед на изображения</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="845"/>
        <source>[*]%1 (Failed to Load) - Image Viewer</source>
        <translation>[*]%1 (Зареждане неуспешно) - Преглед на изображения</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="851"/>
        <source>[*]%1 (%2x%3) - Image Viewer</source>
        <translation>[*]%1 (%2x%3) - Преглед на изображения</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="897"/>
        <source>[*]Image Viewer</source>
        <translation>[*]Преглед на изображения</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1294"/>
        <source>Thumbnails</source>
        <translation>Миниатюри</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1389"/>
        <source>EXIF Data</source>
        <translation>EXIF Данни</translation>
    </message>
</context>
<context>
    <name>LxImage::MruMenu</name>
    <message>
        <location filename="../mrumenu.cpp" line="49"/>
        <source>&amp;Clear</source>
        <translation>&amp;Изчистване</translation>
    </message>
</context>
<context>
    <name>LxImage::PreferencesDialog</name>
    <message>
        <location filename="../preferencesdialog.cpp" line="74"/>
        <source>Use a modifier key to clear a shortcut
in the editing mode.</source>
        <translation>Използване на модифициращ клавиш за изчистване на комбинацията
в режим на редактиране.</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="206"/>
        <source>Bottom</source>
        <translation>Отдолу</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="207"/>
        <source>Top</source>
        <translation>Отгоре</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="208"/>
        <source>Left</source>
        <translation>Ляво</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="334"/>
        <source>&lt;b&gt;Warning: Ambiguous shortcut detected!&lt;/b&gt;</source>
        <translation>&lt;b&gt;Внимание: Беше засечена повтаряща се комбинация!&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="351"/>
        <source>&lt;b&gt;Ambiguous shortcut not accepted.&lt;/b&gt;</source>
        <translation>&lt;b&gt;Внимание: Повтарящата се комбинация не беше приета.&lt;/b&gt;</translation>
    </message>
</context>
<context>
    <name>LxImage::SaveImageJob</name>
    <message>
        <location filename="../saveimagejob.cpp" line="54"/>
        <source>Cannot save with this image format!</source>
        <translation>Запазването в този формат не е възможно!</translation>
    </message>
</context>
<context>
    <name>LxImage::StatusBar</name>
    <message>
        <location filename="../statusbar.cpp" line="63"/>
        <source>Size:</source>
        <translation>Размер:</translation>
    </message>
    <message>
        <location filename="../statusbar.cpp" line="73"/>
        <source>Path:</source>
        <translation>Път:</translation>
    </message>
</context>
<context>
    <name>LxImage::UploadDialog</name>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="52"/>
        <source>Imgur</source>
        <translation>Imgur</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="53"/>
        <source>ImgBB</source>
        <translation>ImgBB</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="54"/>
        <source>ImageShack</source>
        <translation>ImageShack</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="137"/>
        <source>Start</source>
        <translation>Старт</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="140"/>
        <source>Stop</source>
        <translation>Стоп</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="143"/>
        <source>Close</source>
        <translation>Затваряне</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="150"/>
        <source>Error</source>
        <translation>Грешка</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>Image Viewer</source>
        <translation>Преглед на изображения</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="72"/>
        <source>&amp;Recently Opened Files</source>
        <translation>&amp;Последно отваряни файлове</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="224"/>
        <source>&amp;About</source>
        <translation>&amp;Относно</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="204"/>
        <location filename="../mainwindow.ui" line="683"/>
        <source>Annotations Toolbar</source>
        <translation>Лента с инструменти</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="67"/>
        <source>Open &amp;With...</source>
        <translation>Отваряне &amp;с...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="117"/>
        <source>Sorting</source>
        <translation>Сортиране</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="229"/>
        <source>Hidden &amp;Shortcuts</source>
        <translation>Скриване &amp;Клавишни комбинации</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="238"/>
        <source>&amp;Open…</source>
        <translation>&amp;Отваряне…</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="241"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="250"/>
        <source>&amp;Reload File</source>
        <translation>Повторно заре&amp;ждане на файл</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="253"/>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="262"/>
        <source>&amp;Save</source>
        <translation>&amp;Запазване</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="265"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="274"/>
        <source>Save &amp;As</source>
        <translation>Запазване &amp;като</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="277"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="286"/>
        <source>&amp;Close</source>
        <translation>За&amp;тваряне</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="289"/>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="298"/>
        <source>Zoom &amp;In</source>
        <translation>&amp;Увеличаване</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="301"/>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="310"/>
        <source>Zoom &amp;Out</source>
        <translation>&amp;Намаляване</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="313"/>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="322"/>
        <source>&amp;Copy to Clipboard</source>
        <translation>&amp;Копиране в клипборда</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="331"/>
        <location filename="../mainwindow.ui" line="334"/>
        <source>Next File</source>
        <translation>Следващ файл</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="337"/>
        <source>PgDown</source>
        <translation>PgDown</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="346"/>
        <location filename="../mainwindow.ui" line="349"/>
        <source>Previous File</source>
        <translation>Предишен файл</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="352"/>
        <source>PgUp</source>
        <translation>PgUp</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="364"/>
        <source>Original Size</source>
        <translation>Оригинален размер</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="367"/>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="379"/>
        <source>&amp;Fit</source>
        <translation>На&amp;пасване</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="388"/>
        <source>&amp;Rotate Clockwise</source>
        <translation>&amp;Завъртване по часовниковата стрелка</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="391"/>
        <source>R</source>
        <translation>R</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="400"/>
        <source>Rotate &amp;Counterclockwise</source>
        <translation>Завъртване &amp;обратно на часовниковата стрелка</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="403"/>
        <source>L</source>
        <translation>L</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="408"/>
        <source>P&amp;references</source>
        <translation>&amp;Предпочитания</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="413"/>
        <source>&amp;Print</source>
        <translation>Пр&amp;интиране</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="416"/>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="425"/>
        <source>First File</source>
        <translation>Начален файл</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="428"/>
        <source>Home</source>
        <translation>Домашна папка</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="437"/>
        <source>Last File</source>
        <translation>Последен файл</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="440"/>
        <source>End</source>
        <translation>Край</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="449"/>
        <source>&amp;New Window</source>
        <translation>&amp;Нов прозорец</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="452"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="457"/>
        <source>Flip &amp;Horizontally</source>
        <translation>Обърни &amp;хоризонтално</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="460"/>
        <source>H</source>
        <translation>H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="469"/>
        <source>Capture Screenshot</source>
        <translation>Снимка на екрана</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="477"/>
        <source>F&amp;ull Screen</source>
        <translation>П&amp;ълен екран</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="480"/>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="485"/>
        <source>Flip &amp;Vertically</source>
        <translation>Обърни &amp;вертикално</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="488"/>
        <source>V</source>
        <translation>V</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="497"/>
        <source>&amp;Paste from Clipboard</source>
        <translation>&amp;Поставяне от клипборда</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="509"/>
        <source>&amp;Slide Show</source>
        <translation>Про&amp;жекция</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="518"/>
        <source>&amp;Delete</source>
        <translation>&amp;Изтриване</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="521"/>
        <source>Del</source>
        <translation>Del</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="529"/>
        <source>Show Thumbnails</source>
        <translation>Показване на миниатюри</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="532"/>
        <source>T</source>
        <translation>T</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="537"/>
        <source>File Properties</source>
        <translation>Свойства на файл</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="546"/>
        <source>Open &amp;Directory</source>
        <translation>Отваряне на &amp;директория</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="549"/>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="558"/>
        <source>Upload</source>
        <translation>Качване</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="561"/>
        <source>Upload the image</source>
        <translation>Качване на изображение</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="564"/>
        <source>Ctrl+U</source>
        <translation>Ctrl+U</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="572"/>
        <source>Show EXIF Data</source>
        <translation>Показване на EXIF данни</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="584"/>
        <source>No Tool</source>
        <translation>Без инструменти</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="587"/>
        <source>Deselect all drawing tools</source>
        <translation>Премахване на всички инструменти за чертане</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="599"/>
        <source>Draw Arrow</source>
        <translation>Чертаене на стрелка</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="602"/>
        <source>Draw an arrow</source>
        <translation>Чертаене на стрелка</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="614"/>
        <source>Draw Rectangle</source>
        <translation>Чертаене на правоъгълник</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="617"/>
        <source>Draw a hollow rectangle</source>
        <translation>Чертаене на празен правоъгълник</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="629"/>
        <source>Draw Circle</source>
        <translation>Чертаене на кръг</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="632"/>
        <source>Draw a hollow circle</source>
        <translation>Чертаене на празен кръг</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="644"/>
        <source>Draw Number</source>
        <translation>Чертаене на число</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="647"/>
        <source>Draw incrementing numbers</source>
        <translation>Чертаене на нарастващи числа</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="655"/>
        <location filename="../mainwindow.ui" line="658"/>
        <source>Menubar</source>
        <translation>Лента с меню</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="661"/>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="669"/>
        <source>&amp;Main Toolbar</source>
        <translation>&amp;Главна лента с меню</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="672"/>
        <source>Main Toolbar</source>
        <translation>Главна лента с меню</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="680"/>
        <source>&amp;Annotations Toolbar</source>
        <translation>Инструменти за анота&amp;ции</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="691"/>
        <location filename="../mainwindow.ui" line="694"/>
        <source>Show Outline</source>
        <translation>Показване на краища</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="697"/>
        <source>O</source>
        <translation>O</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="705"/>
        <source>Copy Pa&amp;th</source>
        <translation>Копиране на п&amp;ътя</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="708"/>
        <source>Copy path</source>
        <translation>Копиране на пътя</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="716"/>
        <location filename="../mainwindow.ui" line="719"/>
        <source>Rename</source>
        <translation>Преименуване</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="722"/>
        <source>F2</source>
        <translation>F2</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="731"/>
        <source>Resize</source>
        <translation>Преоразмеряване</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="739"/>
        <source>&amp;By File Name</source>
        <translation>&amp;По име на файл</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="742"/>
        <source>By File Name</source>
        <translation>По име на файл</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="750"/>
        <source>By &amp;Modification Time</source>
        <translation>По време на &amp;промяна</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="753"/>
        <source>By Modification Time</source>
        <translation>По време на промяна</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="761"/>
        <source>By C&amp;reation Time</source>
        <translation>По време на &amp;създаване</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="764"/>
        <source>By Creation Time</source>
        <translation>По време на създаване</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="772"/>
        <source>By File &amp;Size</source>
        <translation>По &amp;размер на файла</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="775"/>
        <source>By File Size</source>
        <translation>По размер на файла</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="783"/>
        <source>By File &amp;Type</source>
        <translation>По &amp;тип на файла</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="786"/>
        <source>By File Type</source>
        <translation>По тип на файла</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="63"/>
        <source>&amp;File</source>
        <translation>&amp;Файл</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="97"/>
        <source>&amp;Help</source>
        <translation>&amp;Помощ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="104"/>
        <source>Go</source>
        <translation>Отиди</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="113"/>
        <source>&amp;View</source>
        <translation>&amp;Изглед</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="145"/>
        <source>&amp;Edit</source>
        <translation>&amp;Редактиране</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="169"/>
        <source>Toolbar</source>
        <translation>Лента с инструменти</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../preferencesdialog.ui" line="14"/>
        <source>Preferences</source>
        <translation>Предпочитания</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="33"/>
        <source>Icon theme:</source>
        <translation>Икони:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="53"/>
        <source>Thumbnailer file size limit:</source>
        <translation>Ограничение за файловият размер на миниатюрите:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="151"/>
        <source>Normal background color:</source>
        <translation>Цвят на фона в нормален изглед:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="165"/>
        <source>Fullscreen background color:</source>
        <translation>Цвят на фона при пълен екран:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="43"/>
        <source>Maximum number of recent files:</source>
        <translation>Брой на максимално отворените файлове:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="179"/>
        <source>Slide show interval (seconds):</source>
        <translation>Интервал между изображенията при прожекция (секунди):</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="193"/>
        <source>Show image outline by default</source>
        <translation>Показване на краища на изображение по подразбиране</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="134"/>
        <source>Show annotations toolbar by default</source>
        <translation>Показване на лента с анотации по подразбиране</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="200"/>
        <source>Fit images when navigating</source>
        <translation>Вмести изображенията при навигиране</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="60"/>
        <source> MiB</source>
        <translation> Мибибайт</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="76"/>
        <source>Thumbnail image dimensions:</source>
        <translation>Размер на миниатюрата:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="86"/>
        <source>Use system Trash (and do not prompt)</source>
        <translation>Използване на системното кошче (и без предупреждаване)</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="94"/>
        <source>Window</source>
        <translation>Прозорец</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="103"/>
        <source>Show thumbnails dock by default</source>
        <translation>Покажи мястото за поставяне на миниатюри по подразбиране</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="113"/>
        <source>Show Exif data dock by default</source>
        <translation>Показване на док за Exif данни по подразбиране</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="120"/>
        <source>Show menubar by default</source>
        <translation>Покажи ментата с менюта по подразбиране</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="127"/>
        <source>Show main toolbar by default</source>
        <translation>Покажи главната лента с инструменти по подразбиране</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="142"/>
        <source>Image</source>
        <translation>Изображение</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="207"/>
        <source>Smooth images on zooming</source>
        <translation>Плавни изображения при мащабиране</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="215"/>
        <source>Shortcuts</source>
        <translation>Клавишни комбинации</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="234"/>
        <source>Action</source>
        <translation>Действие</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="239"/>
        <source>Shortcut</source>
        <translation>Комбинация</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="247"/>
        <source>Default</source>
        <translation>По подразбиране</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="24"/>
        <source>General</source>
        <translation>Общи</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../mainwindow.cpp" line="989"/>
        <source>Error</source>
        <translation>Грешка</translation>
    </message>
</context>
<context>
    <name>ResizeImageDialog</name>
    <message>
        <location filename="../resizeimagedialog.ui" line="14"/>
        <source>Resize Image</source>
        <translation>Преоразмеряване на изображение</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="26"/>
        <source>Width</source>
        <translation>Широчина</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="33"/>
        <source>Height</source>
        <translation>Височина</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="40"/>
        <source>Current size:</source>
        <translation>Текущ размер:</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="80"/>
        <source>New size:</source>
        <translation>Нов размер:</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="93"/>
        <location filename="../resizeimagedialog.ui" line="116"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="129"/>
        <location filename="../resizeimagedialog.ui" line="158"/>
        <source> %</source>
        <translation> %</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="174"/>
        <source>Keep aspect ratio</source>
        <translation>Запазване на пропорциите</translation>
    </message>
</context>
<context>
    <name>ScreenshotDialog</name>
    <message>
        <location filename="../screenshotdialog.ui" line="14"/>
        <source>Screenshot</source>
        <translation>Снимка на екрана</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="27"/>
        <source>Take a screenshot</source>
        <translation>Създаване на снимка на екрана</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="34"/>
        <source>Region</source>
        <translation>Област</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="40"/>
        <source>Whole screen</source>
        <translation>Целия екран</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="50"/>
        <source>Current window only</source>
        <translation>Само избрания прозорец</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="57"/>
        <source>Capture an area of the screen</source>
        <translation>Избрана област от екрана</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="67"/>
        <source>Include mouse cursor</source>
        <translation>Зключване на показалеца на мишката</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="74"/>
        <source> sec</source>
        <translation> s</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="91"/>
        <source>Delay:</source>
        <translation>Забавяне:</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="101"/>
        <source>Include window title and frame</source>
        <translation>Включване на заглавие на прозорец и рамка</translation>
    </message>
</context>
<context>
    <name>UploadDialog</name>
    <message>
        <location filename="../upload/uploaddialog.ui" line="14"/>
        <source>Upload</source>
        <translation>Качване</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.ui" line="39"/>
        <source>Copy</source>
        <translation>Копиране</translation>
    </message>
</context>
</TS>
